@@ -103,7 +103,9 @@ module Pantry
   , loadSnapshotLayer
   , loadSnapshot
   , loadAndCompleteSnapshot
+  , loadAndCompleteSnapshot'
   , loadAndCompleteSnapshotRaw
+  , loadAndCompleteSnapshotRaw'
   , CompletedSL (..)
   , CompletedPLI (..)
   , addPackagesToSnapshot
@@ -289,12 +291,8 @@ defaultHackageSecurityConfig = HackageSecurityConfig
   { hscKeyIds =
       [ "0a5c7ea47cd1b15f01f5f51a33adda7e655bc0f0b0615baa8e271f4c3351e21d"
       , "1ea9ba32c526d1cc91ab5e5bd364ec5e9e8cb67179a471872f6e26f0ae773d42"
-      , "280b10153a522681163658cb49f632cde3f38d768b736ddbc901d99a1a772833"
-      , "2a96b1889dc221c17296fcc2bb34b908ca9734376f0f361660200935916ef201"
       , "2c6c3627bd6c982990239487f1abd02e08a02e6cf16edb105a8012d444d870c3"
       , "51f0161b906011b52c6613376b1ae937670da69322113a246a09f807c62f6921"
-      , "772e9f4c7db33d251d5c6e357199c819e569d130857dc225549b40845ff0890d"
-      , "aa315286e6ad281ad61182235533c41e806e5a787e0b6d1e7eef3f09d137d2e9"
       , "fe331502606802feac15e514d9b9ea83fee8b6ffef71335479a2e68d84adc6b0"
       ]
   , hscKeyThreshold = 3
@@ -1166,7 +1164,8 @@ data CompletedPLI = CompletedPLI !RawPackageLocationImmutable !PackageLocationIm
 data CompletedSL = CompletedSL !RawSnapshotLocation !SnapshotLocation
 
 -- | Parse a 'Snapshot' (all layers) from a 'SnapshotLocation' noting
--- any incomplete package locations
+-- any incomplete package locations. Debug output will include the raw snapshot
+-- layer.
 --
 -- @since 0.1.0.0
 loadAndCompleteSnapshot
@@ -1175,11 +1174,25 @@ loadAndCompleteSnapshot
   -> Map RawSnapshotLocation SnapshotLocation -- ^ Cached snapshot locations from lock file
   -> Map RawPackageLocationImmutable PackageLocationImmutable -- ^ Cached locations from lock file
   -> RIO env (Snapshot, [CompletedSL], [CompletedPLI])
-loadAndCompleteSnapshot loc cachedSL cachedPL =
-  loadAndCompleteSnapshotRaw (toRawSL loc) cachedSL cachedPL
+loadAndCompleteSnapshot = loadAndCompleteSnapshot' True
+
+-- | As for 'loadAndCompleteSnapshot' but allows toggling of the debug output of
+-- the raw snapshot layer.
+--
+-- @since 0.5.7
+loadAndCompleteSnapshot'
+  :: (HasPantryConfig env, HasLogFunc env, HasProcessContext env)
+  => Bool -- ^ Debug output includes the raw snapshot layer
+  -> SnapshotLocation
+  -> Map RawSnapshotLocation SnapshotLocation -- ^ Cached snapshot locations from lock file
+  -> Map RawPackageLocationImmutable PackageLocationImmutable -- ^ Cached locations from lock file
+  -> RIO env (Snapshot, [CompletedSL], [CompletedPLI])
+loadAndCompleteSnapshot' debugRSL loc cachedSL cachedPL =
+  loadAndCompleteSnapshotRaw' debugRSL (toRawSL loc) cachedSL cachedPL
 
 -- | Parse a 'Snapshot' (all layers) from a 'RawSnapshotLocation' completing
--- any incomplete package locations
+-- any incomplete package locations. Debug output will include the raw snapshot
+-- layer.
 --
 -- @since 0.1.0.0
 loadAndCompleteSnapshotRaw
@@ -1188,7 +1201,20 @@ loadAndCompleteSnapshotRaw
   -> Map RawSnapshotLocation SnapshotLocation -- ^ Cached snapshot locations from lock file
   -> Map RawPackageLocationImmutable PackageLocationImmutable -- ^ Cached locations from lock file
   -> RIO env (Snapshot, [CompletedSL], [CompletedPLI])
-loadAndCompleteSnapshotRaw rawLoc cacheSL cachePL = do
+loadAndCompleteSnapshotRaw = loadAndCompleteSnapshotRaw' True
+
+-- As for 'loadAndCompleteSnapshotRaw' but allows toggling of the debug output
+-- of the raw snapshot layer.
+--
+-- @since 0.5.7
+loadAndCompleteSnapshotRaw'
+  :: (HasPantryConfig env, HasLogFunc env, HasProcessContext env)
+  => Bool -- ^ Debug output includes the raw snapshot layer
+  -> RawSnapshotLocation
+  -> Map RawSnapshotLocation SnapshotLocation -- ^ Cached snapshot locations from lock file
+  -> Map RawPackageLocationImmutable PackageLocationImmutable -- ^ Cached locations from lock file
+  -> RIO env (Snapshot, [CompletedSL], [CompletedPLI])
+loadAndCompleteSnapshotRaw' debugRSL rawLoc cacheSL cachePL = do
   eres <- case Map.lookup rawLoc cacheSL of
     Just loc -> right (\rsl -> (rsl, (CompletedSL rawLoc loc))) <$> loadSnapshotLayer loc
     Nothing -> loadRawSnapshotLayer rawLoc
@@ -1201,8 +1227,8 @@ loadAndCompleteSnapshotRaw rawLoc cacheSL cachePL = do
             }
       in pure (snapshot, [CompletedSL (RSLCompiler wc) (SLCompiler wc)], [])
     Right (rsl, sloc) -> do
-      (snap0, slocs, completed0) <- loadAndCompleteSnapshotRaw (rslParent rsl) cacheSL cachePL
-      logDebug $ fromString $ show rsl
+      (snap0, slocs, completed0) <- loadAndCompleteSnapshotRaw' debugRSL (rslParent rsl) cacheSL cachePL
+      when debugRSL $ logDebug $ fromString $ show rsl
       (packages, completed, unused) <-
         addAndCompletePackagesToSnapshot
           rawLoc
@@ -1264,21 +1290,21 @@ warnUnusedAddPackagesConfig source (AddPackagesConfig _drops flags hiddens optio
     flags' =
       map
         (\pn ->
-          "Setting flags for non-existent package: " <>
+          "Setting flags for nonexistent package: " <>
           fromString (packageNameString pn))
         (Map.keys flags)
 
     hiddens' =
       map
         (\pn ->
-          "Hiding non-existent package: " <>
+          "Hiding nonexistent package: " <>
           fromString (packageNameString pn))
         (Map.keys hiddens)
 
     options' =
       map
         (\pn ->
-          "Setting options for non-existent package: " <>
+          "Setting options for nonexistent package: " <>
           fromString (packageNameString pn))
         (Map.keys options)
 
@@ -1727,7 +1753,7 @@ runPantryAppClean f = liftIO $ withSystemTempDirectory "pantry-clean" $ \dir ->
           }
         f
 
--- | Load the global hints from Github.
+-- | Load the global hints from GitHub.
 --
 -- @since 0.1.0.0
 loadGlobalHints
