@@ -21,6 +21,7 @@ import Pantry.Storage as X
   , TreeId
   , Unique(..)
   , Version
+  , versionVersion
   , VersionId
   , getBlobKey
   , getPackageNameById
@@ -31,6 +32,10 @@ import Pantry.Storage as X
   , storeBlob
   , migrateAll
   , Key(unBlobKey)
+  , allHackageCabalCount
+  , allBlobsSource
+  , allBlobsCount
+  , allHackageCabalRawPackageLocations
   )
 import Pantry.Types as X
   ( ModuleNameP(..)
